@@ -1,5 +1,7 @@
 """
-Main interface for workdocs service literal definitions.
+Type annotations for workdocs service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/literals.html)
 
 Usage::
 
